#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vector-hashtables
version:              0.1.2.1
visibility:           public
id:                   vector-hashtables-0.1.2.1-1jPf2hpjjts2DUyPjpMZCY
key:                  vector-hashtables-0.1.2.1-1jPf2hpjjts2DUyPjpMZCY
license:              BSD-3-Clause
copyright:            2016-2024 klapaucius, swamp_agr
maintainer:           klapaucius, swamp_agr, ArtemPelenitsyn
author:               klapaucius
homepage:             https://github.com/klapaucius/vector-hashtables#readme
synopsis:             Efficient vector-based mutable hashtables implementation.
description:
    This package provides efficient vector-based hashtable implementation similar to .NET Generic Dictionary implementation (at the time of 2015).

    See "Data.Vector.Hashtables" for documentation.

category:             Data
abi:                  3e097cbf51d2fdd1e095c231d6ac5480
exposed:              True
exposed-modules:
    Data.Primitive.PrimArray.Utils Data.Vector.Hashtables
    Data.Vector.Hashtables.Internal
    Data.Vector.Hashtables.Internal.Mask

import-dirs:          /usr/lib/ghc-9.6.6/site-local/vector-hashtables-0.1.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/vector-hashtables-0.1.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/vector-hashtables-0.1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-hashtables
hs-libraries:         HSvector-hashtables-0.1.2.1-1jPf2hpjjts2DUyPjpMZCY
depends:
    base-4.18.2.1 hashable-1.4.7.0-DeckboSXRoV2uaWXBDn9RA
    primitive-0.9.1.0-5zbRYrfoFPr4oGDF3kIYIh
    vector-0.13.2.0-HJSwbt845rQ2AOZrNm5BDk

haddock-interfaces:
    /usr/share/doc/haskell-vector-hashtables/html/vector-hashtables.haddock

haddock-html:         /usr/share/doc/haskell-vector-hashtables/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

